aboutsummaryrefslogtreecommitdiff
path: root/saga
diff options
context:
space:
mode:
authorJonathan Gray2004-05-01 14:00:53 +0000
committerJonathan Gray2004-05-01 14:00:53 +0000
commit6f33b9225c296b5faa64794f8d68d70ccf19ff31 (patch)
tree571517a45e921a3b4663f134899e9dc801482b15 /saga
parent273be948c07a696271a06ded93b670c7cffabb66 (diff)
downloadscummvm-rg350-6f33b9225c296b5faa64794f8d68d70ccf19ff31.tar.gz
scummvm-rg350-6f33b9225c296b5faa64794f8d68d70ccf19ff31.tar.bz2
scummvm-rg350-6f33b9225c296b5faa64794f8d68d70ccf19ff31.zip
unbreak change that prevented ite disk version from launching, add detection for win32 demo
svn-id: r13711
Diffstat (limited to 'saga')
-rw-r--r--saga/game.cpp34
-rw-r--r--saga/game_mod.h3
2 files changed, 32 insertions, 5 deletions
diff --git a/saga/game_mod.h b/saga/game_mod.h
index b25f149f28..1dafdabf40 100644
--- a/saga/game_mod.h
+++ b/saga/game_mod.h
@@ -38,7 +38,8 @@ enum R_GAME_IDS {
R_GAME_ITE_DISK = 1,
R_GAME_ITE_CD = 2,
R_GAME_IHNM_DEMO = 3,
- R_GAME_IHNM_CD = 4
+ R_GAME_IHNM_CD = 4,
+ R_GAME_ITE_WINDEMO = 5
};
enum R_GAME_FILETYPES {
diff --git a/saga/game.cpp b/saga/game.cpp
index 9b774c0479..6a657c4a0c 100644
--- a/saga/game.cpp
+++ b/saga/game.cpp
@@ -38,7 +38,7 @@
namespace Saga {
// Inherit the Earth - Demo version
R_GAME_FILEDESC ITEDEMO_GameFiles[] = {
{"ITE.RSC", R_GAME_RESOURCEFILE},
@@ -56,6 +56,14 @@ R_GAME_SOUNDINFO ITEDEMO_GameSound = {
R_GAME_SOUND_VOC, 0, 0, 0
};
+// Inherit the Earth - win32 Wyrmkeep Demo version
+R_GAME_FILEDESC ITEWINDEMO_GameFiles[] = {
+ {"ITED.RSC", R_GAME_RESOURCEFILE},
+ {"SCRIPTSD.RSC", R_GAME_SCRIPTFILE},
+ {"SOUNDSD.RSC", R_GAME_SOUNDFILE},
+ {"VOICESD.RSC", R_GAME_VOICEFILE}
+};
+
// Inherit the Earth - Diskette version
R_GAME_FILEDESC ITEDISK_GameFiles[] = {
{"ITE.RSC", R_GAME_RESOURCEFILE} ,
@@ -147,11 +155,11 @@ R_GAME_SOUNDINFO IHNM_GameSound = {
};
R_GAMEDESC GameDescs[] = {
// Inherit the earth - Demo version
{
R_GAMETYPE_ITE,
R_GAME_ITE_DEMO, // Game id
- "Inherit the Earth - Demo version", // Game title
+ "Inherit the Earth - DOS Demo version", // Game title
320, 200, // Logical resolution
137, // Scene viewport height
ITE_DEFAULT_SCENE, // Starting scene number
@@ -165,6 +173,24 @@ R_GAMEDESC GameDescs[] = {
0 // Game supported flag
},
+ // Inherit the earth - win32 Wyrmkeep Demo version
+ {
+ R_GAMETYPE_ITE,
+ R_GAME_ITE_WINDEMO,
+ "Inherit the Earth - Win32 Wyrmkeep Demo version",
+ 320, 200,
+ 137,
+ ITE_DEFAULT_SCENE,
+ &ITE_Resources,
+ ARRAYSIZE(ITEWINDEMO_GameFiles),
+ ITEWINDEMO_GameFiles,
+ ARRAYSIZE(ITECD_GameFonts),
+ ITECD_GameFonts,
+ &ITECD_GameSound,
+ NULL,
+ 0
+ },
+
// Inherit the earth - Disk version
{
R_GAMETYPE_ITE,
@@ -180,7 +206,7 @@ R_GAMEDESC GameDescs[] = {
ITEDISK_GameFonts,
&ITE_GameSound,
Verify_ITEDISK,
- 0
+ 1
},
// Inherit the earth - CD version
@@ -38,7 +38,7 @@
namespace Saga {
-// Inherit the Earth - Demo version
+// Inherit the Earth - DOS Demo version
R_GAME_FILEDESC ITEDEMO_GameFiles[] = {
{"ITE.RSC", R_GAME_RESOURCEFILE},
@@ -147,11 +155,11 @@ R_GAME_SOUNDINFO IHNM_GameSound = {
};
R_GAMEDESC GameDescs[] = {
- // Inherit the earth - Demo version
+ // Inherit the earth - DOS Demo version
{
R_GAMETYPE_ITE,